@@ -25,10 +25,17 @@ for(i in 1:ncol(dataFrame)) {
     cat("A character vector","\n")
   }else{
   if(any(class(dataFrame[,i])=="factor")){
-    table1 <-(t(t(table(dataFrame[,i]))))
-    table1 <- cbind(table1, format(table1/sum(table1)*100, digits=3))
-    colnames(table1) <- c("Frequency","Percent")
-    print.noquote(table1)
+      table1 <-(t(t(table(dataFrame[,i]))))
+      table1 <- cbind(table1, format(table1/sum(table1)*100, digits=3))
+      colnames(table1) <- c("Frequency","Percent")
+    if(is.null(attr(dataFrame, "val.labels")[i])){
+      print.noquote(table1, right=TRUE)
+    }else{
+      table2 <- data.frame(attr(dataFrame, "label.table")[attr(attr(dataFrame,"label.table"), "names")==attr(dataFrame, "val.labels")[i]], table1)
+      colnames(table2) <- c("code", colnames(table1))
+      cat("Label table:", attr(dataFrame, "val.labels")[i], "\n") 
+      print.noquote(table2, right=TRUE)
+    }
     }else{
     summ(dataFrame[,i], graph=FALSE)
     }
@@ -206,7 +213,7 @@ colnames(rpercent)[ncol(rpercent)] <- "Total"
 		}else{
 			string4 <- as.character(substitute(col))
 		}
-names(attr(tab,"dimnames")) <-c(ifelse(nchar(string2)>15,substr(string2,1,15) ,string2), string4)
+names(attr(tab,"dimnames")) <-c(string2, string4)
 cat( "\n")
 cat("Original table", "\n")
 tabtotal <- addmargins(tab)
@@ -216,12 +223,12 @@ print(tabtotal, print.gap=2)
 cat( "\n")
 
 cat("Row percent", "\n")
-names(attr(rpercent,"dimnames")) <- c(ifelse(nchar(string2)>15,substr(string2,1,15) ,string2), string4)
+names(attr(rpercent,"dimnames")) <- c(string2, string4)
 print.table(rpercent, right=TRUE, print.gap=2)
 cat( "\n")
 
 cat("Column percent", "\n")
-names(attr(cpercent,"dimnames")) <- c(ifelse(nchar(string2)>15,substr(string2,1,15) ,string2), string4)
+names(attr(cpercent,"dimnames")) <- c(string2, string4)
 print.table(cpercent, right=TRUE, print.gap=2)
 cat( "\n")
 
@@ -229,8 +236,12 @@ if(graph==TRUE){
 	rownames(tab)[is.na(rownames(tab))] <- "missing"
 	colnames(tab)[is.na(colnames(tab))] <- "missing"
 	las.value <- las
+	if(nchar(paste(titleString()$distribution.of,string4,titleString()$by,string2))>45){
+  	plot(as.table(tab),xlab=string2, ylab=string4, main=paste(titleString()$distribution.of,string4,"\n",titleString()$by,string2),
+	col=c("white",2:length(col)), las=las.value)
+  }else{
 	plot(as.table(tab),xlab=string2, ylab=string4, main=paste(titleString()$distribution.of,string4,titleString()$by,string2),
-	col=c("white",2:length(col)), las=las.value)}
+	col=c("white",2:length(col)), las=las.value)}}
 
 cpercent <- tab
 for(i in 1:ncol(tab)) {cpercent[,i] <- tab[,i]/colSums(tab)[i]*100}
@@ -481,7 +492,7 @@ if(is.null(cctable.dimnames)){
 			string4 <- cctable.dimnames[2]
 			string2 <- cctable.dimnames[1]
 		}
-names(attr(cctable,"dimnames")) <-c(ifelse(nchar(string2)>15,substr(string2,1,15) ,string2), string4)
+names(attr(cctable,"dimnames")) <-c(string2, string4)
 suppressWarnings(return(cctable, caseexp=cctable[2,2], controlex=cctable[1,2], casenonex=cctable[2,1], controlnonex=cctable[1,1]))
 }
 
@@ -1074,6 +1085,7 @@ summ <- function (x=.data, by=NULL, graph=TRUE, box=FALSE) {
 			string4 <- as.character(substitute(by))
 		}
 		string5 <- paste(string3,titleString()$by,string4)
+		if(nchar(string5)>45){string5 <- paste(string3,"\n", titleString()$by,string4)}
 #		if(length(grep("Thai",Sys.getlocale("LC_ALL")))==1){string5<-paste(string3,"ṡ",string4)}
 #		if(length(grep("People's Republic of China",Sys.getlocale("LC_ALL")))==1){string5<-paste(string3,"",string4)}
 #		if(length(grep("Malay",Sys.getlocale("LC_ALL")))==1){string5<-paste(string3,"mengikut",string4)}
@@ -1307,6 +1319,14 @@ for(i in 1:(dim(x)[2])) {
 	else
 	if  (is.factor(x[i][2,])){
 	a[i,2] <- as.character(length(na.omit(x[[i]])))
+#  defactored <- as.integer(as.data.frame(attr(x, "label.table")[attr(attr(x,"label.table"), "names")==attr(x, "val.labels")[i]])[,1])
+#	a[i,3:7] <- round(c(mean(na.omit(defactored)), 
+#			median(na.omit(defactored)), 
+#			sd(na.omit(defactored)), 
+#			min(na.omit(defactored)), 
+#			max(na.omit(defactored))),3)
+
+
 	a[i,3:7] <- round(c(mean(na.omit(unclass(x[i][,]))), 
 			median(na.omit(unclass(x[i][,]))), 
 			sd(na.omit(unclass(x[i][,]))), 
@@ -2118,7 +2138,8 @@ if(is.factor(by0)){
 	glm(xgr~value)->model1
 	xgr.pretty <- model1$coefficient[1] + model1$coefficient[2]*value.pretty 
 	main.lab <- paste(string3,titleString()$by,byname)
-	if(max(y)<20){
+	if(nchar(main.lab)>45){main.lab <- paste(string3,"\n",titleString()$by,byname)}
+  if(max(y)<20){
 	plot(xgr,y, xaxt="n", yaxt="n",
 		xlab=" ",main=main.lab, ylim=c(-1,20),
 		ylab=" ", col=as.numeric(by1), pch=18, ...)
@@ -2257,7 +2278,7 @@ pyramid <- function(age, sex, binwidth=5, inputTable=NULL, printTable=FALSE,
   percent=c("none","each","total"), decimal=3, ...){
 if(is.null(inputTable)){
 agegr <- cut(age, br = ( (min(age, na.rm=TRUE)%/%binwidth)
-:(max(age,na.rm=TRUE)%/%binwidth+1)*binwidth))
+:(max(age,na.rm=TRUE)%/%binwidth+ (max(age,na.rm=TRUE)%%binwidth>0))*binwidth))
 	age.sex.table <- table(agegr, sex, deparse.level=1, dnn=list(substitute(age),substitute(sex)))
 if(ncol(table(agegr,sex))!=2)stop("There must be two genders")
 	age.sex.table.dimnames <- names(attr(age.sex.table,"dimnames"))
